==> qmmp_1.6.2.orig.tar.bz2: qmmp-1.6.2/src/plugins/Input/wavpack/translations/wavpack_plugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>DecoderWavPackFactory</name>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="39"/>
        <source>WavPack Plugin</source>
        <translation>Greffon WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="41"/>
        <source>WavPack Files</source>
        <translation>Fichiers WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="183"/>
        <source>About WavPack Audio Plugin</source>
        <translation>À propos du greffon audio WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="184"/>
        <source>Qmmp WavPack Audio Plugin</source>
        <translation>Greffon audio WavPack pour Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="185"/>
        <source>WavPack library version:</source>
        <translation>Version de la bibliothèque WavPack&#xa0;:</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="187"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Écrit par : Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>WavPackMetaDataModel</name>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="72"/>
        <source>Ratio</source>
        <translation>Taux</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="73"/>
        <source>Version</source>
        <translation>Version</translation>
    </message>
</context>
</TS>

==> qmmp-2.2.6.tar.bz2: qmmp-2.2.6/src/plugins/Input/wavpack/translations/wavpack_plugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>DecoderWavPackFactory</name>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="38"/>
        <source>WavPack Plugin</source>
        <translation>Greffon WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="40"/>
        <source>WavPack Files</source>
        <translation>Fichiers WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="180"/>
        <source>About WavPack Audio Plugin</source>
        <translation>À propos du greffon audio WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="181"/>
        <source>Qmmp WavPack Audio Plugin</source>
        <translation>Greffon audio WavPack pour Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="182"/>
        <source>WavPack library version: %1</source>
        <translation>Version de la librairie WavPack : %1</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="184"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Écrit par : Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>WavPackMetaDataModel</name>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="71"/>
        <source>Ratio</source>
        <translation>Taux</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="72"/>
        <source>Version</source>
        <translation>Version</translation>
    </message>
</context>
</TS>
